@@ -446,10 +446,10 @@ mod feynmann_test {
     fn test_stochastic_measure() {
         let n = 3;
         let init_state = lower_bits_state();
-        let init = [(vec![0, 1, 2], InitialState::FullState(init_state.clone()))];
+        let init = [(vec![0, 1, 2], InitialState::FullState(init_state))];
         let mut state = FeynmanState::<f64>::new_from_initial_states(n, &init);
         assert_eq!(
-            state.stochastic_measure(&vec![1, 2], 0.0),
+            state.stochastic_measure(&[1, 2], 0.0),
             vec![0.25, 0.25, 0.25, 0.25]
         )
     }
@@ -497,7 +497,7 @@ mod feynmann_test {
         let (m, p) = state.measure(&[0], None, 0.0);
 
         assert_eq!(m, 0);
-        assert_eq!(p, 1.0);
+        assert!((p - 1.0).abs() < f64::EPSILON);
 
         let (m, p) = state.measure(
             &[1],
@@ -509,7 +509,7 @@ mod feynmann_test {
         );
 
         assert_eq!(m, 0);
-        assert_eq!(p, 0.5);
+        assert!((p - 0.5).abs() < f64::EPSILON);
     }
 
     #[test]
@@ -528,7 +528,7 @@ mod feynmann_test {
         );
 
         assert_eq!(m, 0);
-        assert_eq!(p, 0.5);
+        assert!((p - 0.5).abs() < f64::EPSILON);
 
         let c = Complex::new(std::f64::consts::FRAC_1_SQRT_2, 0.0);
         for i in 0..2 {
